import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Button, Popup, CellGroup, Cell, Field } from '@antmjs/vantui';
import { postIssueAssigned, deleteTaIssue, postIssueRejct } from '@/services/taissue';
import { warn } from '@/utils/message';
import style from './style.module.less';

export default (props) => {

  const { issue, formData } = props;

  const [loading1, setLoading1] = React.useState(false);
  const [loading2, setLoading2] = React.useState(false);
  const [loading3, setLoading3] = React.useState(false);
  const [show, setShow] = React.useState(false);
  const [processResult, setProcessResult] = React.useState();
  
  // 交办
  const onAssigned = () => {
    try {
      warn(!formData.addr, '请填写地址')
      warn(!formData.locId, '请选择点位')
      warn(!formData.content, '请填写问题描述')
      warn(!formData.typeId, '请选择问题分类')
      warn(!formData.attachList || formData.attachList.length < 1, '请上传照片')
      warn(!formData.orgId, '请选择交办单位')
      warn(!formData.expireDate, '请选择办结时间')
    } catch (e) {
      return;
    }

    setLoading1(true)
    postIssueAssigned({ ...issue, formData }).then(() => {
      setLoading1(false);
      Taro.navigateBack({delta: 1});
    }).catch(() => {
      setLoading1(false);
    })
  }

  const onDelete = () => {
    Taro.showModal({
      title: '删除',
      content: '确定进行删除操作?',
      success (res) {
        if (res.confirm) {
          setLoading2(true)
          deleteTaIssue(issue.issueId).then(() => {
            setLoading2(false);
            Taro.navigateBack({delta: 1});
          }).catch(() => {
            setLoading2(false);
          })
        }
      }
    })
  }

  const onReject = () => {
    try {
      warn(!processResult, '请填写退单理由')
    } catch (e) {
      return;
    }

    setShow(false);

    const data = {
      processResult,
      issueId: issue.issueId,
    }

    setLoading3(true)
    postIssueRejct(data).then(() => {
      setLoading3(false);
      Taro.navigateBack({delta: 1});
    }).catch(() => {
      setLoading3(false);
    })
  }
  
  return (
    <View class={style['assigned-btn-wrapper']}>
      <Popup position="bottom" show={show} onClose={() => setShow(false)}>
        <CellGroup>
          <Cell title="退单理由" />
          <Field
            type="textarea"
            placeholder="请输入退单理由"
            value={processResult}
            autosize={{ minHeight: '240px' }}
            onChange={e => setProcessResult(e.detail)}
          />
          <View style={{display: 'flex', justifyContent: 'space-around'}}>
            <Button plain type="default" onClick={() => setShow(false)}>取消</Button>
            <Button plain type="primary" onClick={onReject}>确定</Button>
          </View>
        </CellGroup>
      </Popup>
      <View>          
        <Button
          block
          type="primary"
          loading={loading1}
          disabled={loading2 && loading3}
          onClick={onAssigned}
        >交办</Button>
      </View>
      <View style={{marginTop: '20px', display: 'flex'}}>
        <Button
          plain
          hairline
          type="danger"
          loading={loading2}
          disabled={loading1 && loading3}
          style={{ flex: 1 }}
          onClick={onDelete}
        >删除</Button>
        <Button
          plain
          hairline
          type="info"
          loading={loading3}
          disabled={loading1 && loading2}
          style={{ flex: 1, marginLeft: 'var(--main-space)' }}
          onClick={() => setShow(true)}
        >退单</Button>
      </View>
    </View>
  )
}
