import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Button, Notify, Field, Cell, CellGroup } from '@antmjs/vantui';
import LocType from '@/components/LocType';
import IssueType from '@/components/IssueType';
import Map from '@/components/map';
import Uploader from '@/components/Uploader/index';
import mapIcon from '@/assets/icons/marker.png';

export default (props) => {
  const { issue, renderAction } = props;

  const [formData, setFormData] = React.useState({
    typeId: undefined,
    typeName: undefined,
    locId: undefined,
    locName: undefined,
    location: undefined,
    addr: undefined,
    content: undefined,
    attachList: [],
  });
  const [showLocType, setShowLocType] = React.useState(false);
  const [showIssueType, setShowIssueType] = React.useState(false);
  
  const onLocTypeChange = (_, it) => {
    setFormData({
      ...formData,
      locId: it.typeId,
      locName: it.name,
    });
    setShowLocType(false);
  }

  const onIssueTypeChange = (_, it) => {
    setFormData({
      ...formData,
      typeId: it.typeId,
      typeName: it.name,
    });
    setShowIssueType(false);
  }

  const onFieldChange = (field, value) => {
    setFormData({
      ...formData,
      [field]: value,
    })
  }

  React.useEffect(() => {
    if (issue) {
      setFormData(issue);
    }
  }, [issue]);
  
  return (
    <View>
      <LocType
        show={showLocType}
        value={formData.addr}
        onCancel={() => setShowLocType(false)}
        onChange={onLocTypeChange}
      />

      <IssueType
        show={showIssueType}
        value={formData.typeName}
        onCancel={() => setShowIssueType(false)}
        onChange={onIssueTypeChange}
      />

      <Map location={formData.location} />

      <CellGroup>
        <Cell
          isLink
          title="点位"
          value={formData.locName}
          onClick={() => setShowLocType(true)}
        />
        <Field
          value={formData.addr}
          leftIcon={mapIcon}
          placeholder="请输入地址"
          onChange={e => onFieldChange('addr', e.detail)}
        />
      </CellGroup>

      <CellGroup style={{marginTop: '20px'}}>

        <Cell
          isLink
          title="问题分类"
          style={{marginTop: '20px'}}
          value={formData.typeName}
          onClick={() => setShowIssueType(true)}
        />
        <Cell title="问题描述" border={false} />

        <Field
          type="textarea"
          placeholder="请输入问题描述"
          autosize={{ minHeight: '120px' }}
          value={formData.content}
          onChange={e => onFieldChange('content', e.detail)}
        />
      </CellGroup>
            
      <CellGroup style={{marginTop: '20px'}}>        
        <Cell title="拍照或视频" border={false} />

        <Cell
          renderTitle={
            <Uploader value={formData.attachList} onChange={e => onFieldChange('attachList',e)} />
          }
        />
      </CellGroup>

      <View style={{margin: '20px auto'}}>
        {renderAction(formData)}
      </View>
    </View>
  )
}
