import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Cell, CellGroup, Field, Button } from '@antmjs/vantui';
import Page from '@/layouts/index';
import Uploader from '@/components/Uploader/index';
import { getTaIssueById } from '@/services/taissue';
import { getTaOrgIssueByIssueId } from '@/services/taorgissue';

const getDtStr = dt => !dt ? '' : dt.replace('T', ' ').substring(0, 16)

export default (props) => {

  const router = Taro.useRouter();
  const { id } = router.params;

  const [loading, setLoading] = React.useState(false);
  const [issue, setIssue] = React.useState();
  const [orgIssue, setOrgIssue] = React.useState();

  const setFormData = (key, value) => {
    setOrgIssue({
      ...(orgIssue || {}),
      [key]: value,
    })
  }

  React.useEffect(() => {
    if (id) {
      setLoading(true)
      getTaIssueById(id).then(res => {
        setLoading(false);
        setIssue(res);
      }).catch(() => {
        setLoading(false);
      });

      getTaOrgIssueByIssueId(id).then(res => setOrgIssue(res));
    }
  }, [id]);
  
  return (
    <Page loading={loading}>
      <CellGroup>
        <Cell title="上报时间" value={getDtStr(issue?.createDate)} />
        <Cell title="办结时间" value={issue?.expireDate} /> 
      </CellGroup>
      <CellGroup style={{marginTop: '20px'}}>
        <Cell title="抽检位置" value={issue?.locName} />
        <Cell title="定 位 点" value={issue?.addr} />
        <Cell title="问题详情" />        
        <Field
          readonly
          type="textarea"
          autosize={{ minHeight: '120px' }}
          value={issue?.content}
        /> 
        <Cell
          renderTitle={
            <Uploader
              disabled
              value={issue?.attachList}
            />
          }
        />
      </CellGroup>
      <CellGroup style={{marginTop: '20px'}}>
        <Cell title="整改结果" />        
        <Field
          readonly
          type="textarea"
          autosize={{ minHeight: '120px' }}
          value={orgIssue?.result}
          onChange={e => setFormData('result', e.detail)}
        />
        <Cell
          renderTitle={
            <Uploader
              disabled
              value={orgIssue?.attachList}
              onChange={e => setFormData('attachList', e)}
            />
          }
        />
      </CellGroup>
      <View style={{marginTop: '20px', padding: 'var(--main-space)'}}>
        <View>
          <Button block type="primary">通过审核</Button>
        </View>
        <View style={{marginTop: '20px'}}>
          <Button block type="default">重新整改</Button>
        </View>
      </View>
    </Page>
  )
}
